#
# spec file for package python-python-lsp-server
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-python-lsp-server
Version:        1.13.0
Release:        1.1
Summary:        Python Language Server for the Language Server Protocol
License:        MIT
URL:            https://github.com/python-lsp/python-lsp-server
Source:         https://files.pythonhosted.org/packages/source/p/python-lsp-server/python_lsp_server-%{version}.tar.gz
Patch1:         unpin-autopep8.patch
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 61.2}
BuildRequires:  %{python_module setuptools_scm >= 3.4.3}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros >= 20210628
# SECTION test requirements
BuildRequires:  %{python_module autopep8 >= 2.0.4}
BuildRequires:  %{python_module black}
BuildRequires:  %{python_module docstring-to-markdown}
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module importlib_metadata > 4.8.3 if %python-base < 3.10}
BuildRequires:  %{python_module jedi >= 0.17.2 with %python-jedi < 0.20}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pluggy}
BuildRequires:  %{python_module pydocstyle >= 6.3.0 with %python-pydocstyle < 6.4.0}
BuildRequires:  %{python_module pylint >= 3.1 with %python-pylint < 4}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-lsp-jsonrpc >= 1.1.0 with %python-python-lsp-jsonrpc < 2}
BuildRequires:  %{python_module rope >= 1.2.0}
BuildRequires:  %{python_module ujson >= 3.0.0}
BuildRequires:  %{python_module websockets >= 10.3}
BuildRequires:  %{python_module whatthepatch >= 1.0.2 with %python-whatthepatch < 2}
BuildRequires:  %{python_module yapf >= 0.33}
# flake8 is special, see below
BuildRequires:  %{python_module flake8 >= 7.2 with %python-flake8 < 8}
BuildRequires:  %{python_module mccabe >= 0.7.0 with %python-mccabe < 0.8.0}
BuildRequires:  %{python_module pycodestyle >= 2.14.0 with %python-pycodestyle < 2.15.0}
BuildRequires:  %{python_module pyflakes >= 3.4.0 with %python-pyflakes < 3.5.0}
# /SECTION
BuildRequires:  fdupes
Requires:       python-black
Requires:       python-docstring-to-markdown
Requires:       python-pluggy >= 1.0.0
Requires:       python-ujson >= 3.0.0
Requires:       (python-jedi >= 0.17.2 with python-jedi < 0.20)
Requires:       (python-python-lsp-jsonrpc >= 1.1.0 with python-python-lsp-jsonrpc < 2)
%if 0%{?python_version_nodots} < 310
Requires:       python-importlib_metadata >= 4.8.3
%endif
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
Python Language Server for the Language Server Protocol

Fork of the python-language-server project, maintained by
the Spyder IDE team and the community

If the respective recommended packages are installed, the following optional providers
will be enabled:

- Rope for Completions and renaming
- Pyflakes linter to detect various errors
- McCabe linter for complexity checking
- pycodestyle linter for style checking
- pydocstyle linter for docstring style checking (disabled by default)
- autopep8 for code formatting
- YAPF for code formatting (preferred over autopep8)

%package all
Summary:        The python-lsp-server[all] extra
Requires:       python-autopep8 >= 2.0.4
Requires:       python-rope >= 1.2.0
Requires:       python-yapf >= 0.33
Requires:       (python-pydocstyle >= 6.3.0 with python-pydocstyle < 6.4.0)
Requires:       (python-pylint >= 3.1 with python-pylint < 4)
Requires:       (python-whatthepatch >= 1.0.2 with python-whatthepatch < 2)
# Let's bump this in sync with flake8 and ignore pylsp upstream being still behind
# https://flake8.pycqa.org/en/latest/faq.html#why-does-flake8-use-ranges-for-its-dependencies
Requires:       (python-flake8 >= 7.2 with python-flake8 < 8)
Requires:       (python-mccabe >= 0.7.0 with python-mccabe < 0.8.0)
Requires:       (python-pycodestyle >= 2.14.0 with python-pycodestyle < 2.15.0)
Requires:       (python-pyflakes >= 3.3.0 with python-pyflakes < 3.5.0)

%description all
Python Language Server for the Language Server Protocol

This package provides the dependencies for the pip
python-lsp-server[all] extra requirement

%prep
%autosetup -p1 -n python_lsp_server-%{version}
# Remove pytest addopts
sed -i '/addopts/d' pyproject.toml
# see flake8 comment above, check
# https://github.com/PyCQA/flake8/blob/main/setup.cfg
sed -i  pyproject.toml \
    -e 's/flake8>=7.1,<8/flake8>=7.2,<8/' \
    -e 's/pycodestyle>=2.12.0,<2.13.0/pycodestyle>=2.14.0,<2.15.0/' \
    -e 's/pyflakes>=3.2.0,<3.3.0/pyflakes>=3.4.0,<3.5.0/'

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pylsp
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# PyQt5 not maintained anymore. Reenable when upstream moves to PyQt6
%pytest -k "not test_pyqt_completion"

%post
%python_install_alternative pylsp

%postun
%python_uninstall_alternative pylsp

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/pylsp
%{python_sitelib}/pylsp
%{python_sitelib}/python_lsp_server-%{version}.dist-info

%files %{python_files all}
%doc README.md
%license LICENSE

%changelog
* Wed Jul 23 2025 Ben Greiner <code@bnavigator.de>
- Update to 1.13.0
  * Format signatures in docstrings.
  * Add support for type definition.
  * Send websocket payload using a queue.
  * Fix getting symbols with inline comments that include the
    import word.
  * Drop support for Python 3.8
* Thu May 29 2025 Ben Greiner <code@bnavigator.de>
- Bump flake8 dependencies
- Remove PyQt5 test dependency and skip the one test using it
* Mon Apr 28 2025 Dirk Müller <dmueller@suse.com>
- update to 1.12.2:
  * PR 608 - Fix putting `extra_paths` in front of `sys.path`
* Sun Feb  9 2025 Ben Greiner <code@bnavigator.de>
- Update to 1.12.1
  * Fixes compatibility with Python 3.13 in the test suite.
  * Handles correctly a null value for ropeFolder in the Rope
    configuration.
- Drop pylsp-issues-602-605.patch
* Wed Dec 25 2024 Ben Greiner <code@bnavigator.de>
- Add pylsp-issues-602-605.patch
  * Changed fuzzy jedi completion
    gh#python-lsp/python-lsp-server#602
  * Disable DEBUG logging for tests
    gh#python-lsp/python-lsp-server#605
* Tue Nov 19 2024 Dirk Müller <dmueller@suse.com>
- add unpin-autopep8.patch
* Sun Sep  8 2024 Ben Greiner <code@bnavigator.de>
- Add [all] extra subpackage
* Thu Aug 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.12.0
  * Add support for window/logMessage.
  * Add version support to workspace/publishDiagnostics.
  * Add extendSelect option to flake8 plugin.
  * Allow Jedi's extra_paths to be placed in front of sys.path.
  * Bump flake8 to 7.1
* Thu Jul 11 2024 Ben Greiner <code@bnavigator.de>
- Bump flake8 to 7.1 and it's pinning pycodestyle to 2.12.0
* Mon Apr  1 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.11.0
  * Remove the rope_rename plugin. People that were using it need
    to install the pylsp-rope third-party plugin instead.
  * Add support for Pylint 3.1
- Drop pylsp-pr543-pylint3.1.patch
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Add pylsp-pr543-pylint3.1.patch
  gh#python-lsp/python-lsp-server#531
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 1.10.1:
  * Issue 529 - Autoimports: sqlite3.OperationalError: database
    is locked (PR 530 by @last-partizan)
* Sat Mar  2 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.10.0
  * Add support for notebook document completions.
  * Add support for flake8 version 7.
- Drop python-lsp-server-pr510-flake8-7.patch
* Fri Jan  5 2024 Ben Greiner <code@bnavigator.de>
- Bump to flake8 v7 gh#python-lsp/python-lsp-server#510
  * python-lsp-server-pr510-flake8-7.patch
* Fri Nov 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.9.0
  * Support initializationOptions to configure the server.
  * Add code completions to the autoimport plugin.
  * Add support for Pylint 3.
  * Pass extendIgnore argument to Flake8.
  * Add new pylsp_workspace_configuration_changed hookspec so that
    plugins can react when client sends a configuration change to
    the server.
* Thu Nov  9 2023 Giacomo Comes <gcomes.obs@gmail.com>
- add sle15_python_module_pythons
* Wed Nov  1 2023 Ben Greiner <code@bnavigator.de>
- Fix runtime requirements
* Sun Oct 29 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.8.2
  * Fixes the notebook document selector property not being a list in the server capabilities.
- Release 1.8.1
  * Fixes go-to-definition for Numpy methods.
  * Allows Jedi to perform multiple hops for "go to definition".
  * Fixes an error with Flake8 when deleting lines.
- Raise pylint upper pin to 3.1
* Wed Sep 13 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.8.0
  * Add support for notebooks and make go-to-definition work for
    them.
  * Add support for Pyflakes 3.1, Pycodestyle 2.11 and Jedi 0.19.
  * Drop support for Python 3.7.
- Drop patches upstreeam
  * Drop python-lsp-server-pr415-flake8deps.patch
  * Drop python-lsp-server-pr416-jedi-0.19.patch
* Sat Aug 12 2023 Ben Greiner <code@bnavigator.de>
- Add python-lsp-server-pr415-flake8deps.patch
  gh#python-lsp/python-lsp-server#415
- Add python-lsp-server-pr416-jedi-0.19.patch
  gh#python-lsp/python-lsp-server#416
* Sat Jul  1 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.7.4
  * Fixes token initialization when reporting progress.
  * Resolves home dir references in Jedi environment path.
  * Fixes Pylint hanging on files with many errors.
- Release 1.7.3
  * Adds support for Yapf 0.33
    (upstreamed python-lsp-server-pr377-unpin-yapf.patch)
  * Fix an empty current working directory value for Pylint
* Tue May  9 2023 Ben Greiner <code@bnavigator.de>
- Unpin yapf
  * Add python-lsp-server-pr377-unpin-yapf.patch
  * gh#python-lsp/python-lsp-server#377
* Thu Apr 27 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.7.2
  * Initializes LSP progress token before using it and remove
    progress for sync plugins.
  * Adds support for pydocstyle 6.3
  * Adds support for autopep8 2
- Drop pylsp-pr340-pydocstyle-6.3.patch
- Drop pylsp-pr345-autopep8-2.patch
* Wed Jan 25 2023 Ben Greiner <code@bnavigator.de>
- Allow 1.6.0 <= autopep8 < 2.1
  * Add pylsp-pr345-autopep8-2.patch
  * gh#python-lsp/python-lsp-server#345
- Fix yapf requirement for toml
  * gh#python-lsp/python-lsp-server#346
* Thu Jan 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.7.1
  * Fixes an error with the Pydocstyle 6.2.0+
  * Includes missing Pylint "information" category.
  * Improves Jedi file completions for directories.
- Drop python-lsp-server-pr327-sys-executable.patch
- Add pylsp-pr340-pydocstyle-6.3.patch
  gh#python-lsp/python-lsp-server#340
* Fri Dec 30 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.7.0
  * Add a new plugin to provide autoimport functionality (disabled
    by default).
  * Add progress reporting.
  * Make jedi_definition plugin follow definitions to pyi files.
  * Add support for flake8 version 6.
  * Add support for Yapf ignore patterns.
  * Add mccabe setting to flake8 plugin.
- Drop python-lsp-server-pr316-flake8v6.patch upstreamed
  * gh#python-lsp/python-lsp-server#316
- Add python-lsp-server-pr327-sys-executable.patch
  * gh#python-lsp/python-lsp-server#327
* Mon Dec 19 2022 Ben Greiner <code@bnavigator.de>
- add python-lsp-server-pr316-flake8v6.patch
  gh#python-lsp/python-lsp-server#316
* Sun Nov  6 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.6.0
  * Migrate to MarkupContent and convert docstrings to Markdown by
    default.
  * Add support for flake8 version 5.
  * Add function objects to Jedi completions.
  * Don't include class and functions objects by default in Jedi
    completions.
- Drop patches
  * python-lsp-server-advanceflake8.patch
  * python-lsp-server-pylint-syntax-error.patch
* Sat Aug 27 2022 Ben Greiner <code@bnavigator.de>
- Add python-lsp-server-advanceflake8.patch
  * gh#python-lsp/python-lsp-server#257
- Add python-lsp-server-pylint-syntax-error.patch
  * gh#python-lsp/python-lsp-server#258
* Mon Jul 25 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.5.0
  * Add DiagnosticTag tags for Pylint, Pycodestyle, and Flake8
    plugins.
  * Add support to connect to the server through websockets.
  * Allow multiple per-file-ignores for the same pattern in Flake8
    plugin.
  * Parse YAPF diffs into TextEdits.
  * Add support for LSP formatting options parameter.
- Entry point installation require setuptools 61.2, switch to
  PEP517
- Test suite: flavored alternatives are provided by the %%pytest
  macro now. Remove extra pylint testbin setup.
* Sat Apr  9 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.4.1
  * Fixes Yapf formatting with CRLF line endings.
* Fri Mar 25 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.4.0
  * Support pycodestyle indent-size option
  * Add DiagnosticTag constants from LSP 3.15
  * Drop support for Python 3.6
* Sat Jan  8 2022 Benjamin Greiner <code@bnavigator.de>
- Provide pylint in correct flavor for test
- Cleanup python36 flavor conditionals
* Sun Dec 19 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.3.3
  * Fix error when resolving completion items for Rope
- Drop python-lsp-server-pr133-pylint-python310.patch merged
* Sat Dec 11 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.3.2
  * Fix formatting a log message
- Add python-lsp-server-pr133-pylint-python310.patch
* Fri Nov 26 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.3.1
  * Fix tests for Jedi 0.18.1
  * Option `jedi_completion.resolve_at_most_labels` was renamed to
    `jedi_completion.resolve_at_most` because now it controls how
    many labels and snippets will be resolved per request.
  * Option `jedi_completion.cache_labels_for` was renamed to
    `jedi_completion.cache_for` because now it controls the modules
    for which labels and snippets should be cached.
  * Update requirements on Pylint, flake8, pycodestyle, pyflakes
    and autopep8.
- Drop python-lsp-server-pr102-unpin-flake8.patch
* Sat Nov 20 2021 Ben Greiner <code@bnavigator.de>
- Fix pyflakes python-lsp-server-pr102-unpin-flake8.patch
* Sun Nov 14 2021 Ben Greiner <code@bnavigator.de>
- Add python-lsp-server-pr102-unpin-flake8.patch with excessive
  BR pinning of other optional dependencies
* Wed Oct 27 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.2.4
  * Pin flake8 to be less than version 4.
  * Fix a pylint test when PyLsp is not installed.
* Sun Oct  3 2021 Ben Greiner <code@bnavigator.de>
- Unpin pylint gh#python-lsp/python-lsp-server#94
* Thu Sep  2 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.2.2
  * Improves the way we skip symbols imported from other libraries.
  * Add a constrain on Pylint (< 2.10) until we figure out how to
    support it.
- Reflect the above upper pinning for python-pylint in Suggests
  and Conflicts in order to prevent updates on live systems as soon
  as pylint is updated in Factory
* Thu Aug  5 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.2.1
  * Implement completion item resolve requests for faster
    completions.
  * Initialize workspaces from the initialize request.
  * Catch errors when getting docstrings on _resolve_completion
* Tue Jul 13 2021 Ben Greiner <code@bnavigator.de>
- Initial specfile for version 1.1.0
  * Community maintained replacement for
    python-python-language-server (abandoned by upstream).
  * Required by spyder
